==> haskell-skylighting-core-0.14.2-20-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.2
visibility:           public
id:                   skylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE
key:                  skylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  f95ea5d8a459581472f1f8532aa5a29e
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    colour-2.3.6-5TQtDkpBL6qIeyTKm1JGVg containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-FBimV6u2RMNDKpiH5qP0vN text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14.3-11-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.3
visibility:           public
id:                   skylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4
key:                  skylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  766e8958501b23d6cf3531523727de6c
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    colour-2.3.6-Es9wrqLKeClLAeJW79jO2p containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
